summaryrefslogtreecommitdiff
path: root/src/lib/film.h
diff options
context:
space:
mode:
authorCarl Hetherington <cth@carlh.net>2024-01-17 23:41:23 +0100
committerCarl Hetherington <cth@carlh.net>2024-01-17 23:41:23 +0100
commit7cb1677e10b9692698ede5741c50d8c4b4144ddf (patch)
treea24f02980936d0ade5a07d63e141b3d8e5649a5f /src/lib/film.h
parent678dd30fea0434c6febe4badc47e7aa05ebe58bc (diff)
Move burnt subtitle checks into ::subtitle_languages().
Diffstat (limited to 'src/lib/film.h')
-rw-r--r--src/lib/film.h6
1 files changed, 4 insertions, 2 deletions
diff --git a/src/lib/film.h b/src/lib/film.h
index 1341be8a3..13be4b8db 100644
--- a/src/lib/film.h
+++ b/src/lib/film.h
@@ -192,8 +192,10 @@ public:
return _audio_language;
}
- /** @return pair containing the main subtitle language, and additional languages */
- std::pair<boost::optional<dcp::LanguageTag>, std::vector<dcp::LanguageTag>> subtitle_languages () const;
+ /** @param burnt_in If non-null, filled with true if all subtitles are burnt in, otherwise false.
+ * @return pair containing the main subtitle language, and additional languages
+ */
+ std::pair<boost::optional<dcp::LanguageTag>, std::vector<dcp::LanguageTag>> subtitle_languages(bool* burnt_in = nullptr) const;
/** @return all closed caption languages in the film */
std::vector<dcp::LanguageTag> closed_caption_languages() const;